@@ -60,7 +60,7 @@ static GOptionEntry entries[] = {
   { "indent-spaces", 'i', 0, G_OPTION_ARG_INT, &indent_spaces, N_("Indentation spaces"), N_("SPACES") },
   { "output", 'o', 0, G_OPTION_ARG_FILENAME, &output, N_("Output file"), N_("FILE") },
   { G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_FILENAME_ARRAY, &files, NULL, N_("FILE…") },
-  { NULL },
+  { NULL, 0, 0, 0, NULL, NULL, NULL },
 };
 
 static gboolean
