@@ -1,8 +1,10 @@
 /* json-gobject-private.h - GObject private
  * 
  * This file is part of JSON-GLib
- * Copyright (C) 2007  OpenedHand Ltd
- * Copyright (C) 2009  Intel Corp.
+ *
+ * SPDX-FileCopyrightText: 2007  OpenedHand Ltd
+ * SPDX-FileCopyrightText: 2009  Intel Corp.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -21,8 +23,7 @@
  *   Emmanuele Bassi  <ebassi@linux.intel.com>
  */
 
-#ifndef __JSON_GOBJECT_PRIVATE_H__
-#define __JSON_GOBJECT_PRIVATE_H__
+#pragma once
 
 #include "json-gobject.h"
 
@@ -35,5 +36,3 @@ gboolean  json_deserialize_pspec (GValue       *value,
                                   JsonNode     *node);
 
 G_END_DECLS
-
-#endif /* __JSON_GOBJECT_PRIVATE_H__ */
