@@ -91,6 +91,8 @@ struct _JsonParserPrivate
   gchar *variable_name;
   gchar *filename;
 
+  bool multi_root;
+
   guint has_assignment : 1;
   guint is_filename    : 1;
   guint is_immutable   : 1;
@@ -144,6 +146,8 @@ json_parser_clear (JsonParser *parser)
   g_clear_pointer (&priv->variable_name, g_free);
   g_clear_pointer (&priv->last_error, g_error_free);
   g_clear_pointer (&priv->root, json_node_unref);
+
+  priv->multi_root = false;
 }
 
 static inline void
@@ -724,9 +728,10 @@ json_parse_array (JsonParser    *parser,
       /* look for trailing commas */
       if (next_token == JSON_TOKEN_COMMA)
         {
-          token = json_scanner_get_next_token (scanner);
-          next_token = json_scanner_peek_next_token (scanner);
+          /* advance the cursor */
+          json_scanner_get_next_token (scanner);
 
+          next_token = json_scanner_peek_next_token (scanner);
           if (next_token == JSON_TOKEN_RIGHT_BRACE)
             {
               priv->error_code = JSON_PARSER_ERROR_TRAILING_COMMA;
@@ -827,7 +832,8 @@ json_parse_object (JsonParser    *parser,
         }
 
       /* member name */
-      token = json_scanner_get_next_token (scanner);
+      json_scanner_get_next_token (scanner);
+
       name = json_scanner_dup_string_value (scanner);
       if (name == NULL)
         {
@@ -899,10 +905,10 @@ json_parse_object (JsonParser    *parser,
       next_token = json_scanner_peek_next_token (scanner);
       if (next_token == JSON_TOKEN_COMMA)
         {
-          token = json_scanner_get_next_token (scanner);
-          next_token = json_scanner_peek_next_token (scanner);
+          json_scanner_get_next_token (scanner);
 
           /* look for trailing commas */
+          next_token = json_scanner_peek_next_token (scanner);
           if (next_token == JSON_TOKEN_RIGHT_CURLY)
             {
               priv->error_code = JSON_PARSER_ERROR_TRAILING_COMMA;
@@ -980,8 +986,45 @@ json_parse_statement (JsonParser  *parser,
           priv->error_code = JSON_PARSER_ERROR_INVALID_STRUCTURE;
           return JSON_TOKEN_EOF;
         }
-      JSON_NOTE (PARSER, "Statement is object declaration");
-      return json_parse_object (parser, scanner, &priv->root, 0);
+      else if (priv->root != NULL)
+        {
+          JsonArray *array;
+
+          if (!priv->multi_root)
+            {
+              JSON_NOTE (PARSER, "Replacing new root with an array");
+
+              JsonNode *old_root = g_steal_pointer (&priv->root);
+              priv->root = json_node_new (JSON_NODE_ARRAY);
+
+              array = json_array_new ();
+              json_array_add_element (array, old_root);
+              json_node_set_parent (old_root, priv->root);
+
+              json_node_take_array (priv->root, array);
+
+              priv->multi_root = true;
+            }
+          else
+            {
+              g_assert (JSON_NODE_HOLDS_ARRAY (priv->root));
+              array = json_node_get_array (priv->root);
+            }
+
+          JsonNode *node = NULL;
+          guint res;
+
+          res = json_parse_object (parser, scanner, &node, 0);
+          if (node != NULL)
+            json_array_add_element (array, node);
+          return res;
+        }
+      else
+        {
+          JSON_NOTE (PARSER, "Statement is object declaration");
+          return json_parse_object (parser, scanner, &priv->root, 0);
+        }
+      break;
 
     case JSON_TOKEN_LEFT_BRACE:
       if (priv->is_strict && priv->root != NULL)
@@ -991,8 +1034,45 @@ json_parse_statement (JsonParser  *parser,
           priv->error_code = JSON_PARSER_ERROR_INVALID_STRUCTURE;
           return JSON_TOKEN_EOF;
         }
-      JSON_NOTE (PARSER, "Statement is array declaration");
-      return json_parse_array (parser, scanner, &priv->root, 0);
+      else if (priv->root != NULL)
+        {
+          JsonArray *array;
+
+          if (!priv->multi_root)
+            {
+              JSON_NOTE (PARSER, "Replacing new root with an array");
+
+              JsonNode *old_root = g_steal_pointer (&priv->root);
+              priv->root = json_node_new (JSON_NODE_ARRAY);
+
+              array = json_array_new ();
+              json_array_add_element (array, old_root);
+              json_node_set_parent (old_root, priv->root);
+
+              json_node_take_array (priv->root, array);
+
+              priv->multi_root = true;
+            }
+          else
+            {
+              g_assert (JSON_NODE_HOLDS_ARRAY (priv->root));
+              array = json_node_get_array (priv->root);
+            }
+
+          JsonNode *node = NULL;
+          guint res;
+
+          res = json_parse_array (parser, scanner, &node, 0);
+          if (node != NULL)
+            json_array_add_element (array, node);
+          return res;
+        }
+      else
+        {
+          JSON_NOTE (PARSER, "Statement is array declaration");
+          return json_parse_array (parser, scanner, &priv->root, 0);
+        }
+      break;
 
     /* some web APIs are not only passing the data structures: they are
      * also passing an assigment, which makes parsing horribly complicated
@@ -1014,7 +1094,7 @@ json_parse_statement (JsonParser  *parser,
           }
 
         /* swallow the 'var' token... */
-        token = json_scanner_get_next_token (scanner);
+        json_scanner_get_next_token (scanner);
 
         /* ... swallow the variable name... */
         next_token = json_scanner_get_next_token (scanner);
@@ -1046,7 +1126,7 @@ json_parse_statement (JsonParser  *parser,
         next_token = json_scanner_peek_next_token (scanner);
         if (next_token == ';')
           {
-            token = json_scanner_get_next_token (scanner);
+            json_scanner_get_next_token (scanner);
             return JSON_TOKEN_NONE;
           }
 
