@@ -1,3 +1,11 @@
+// SPDX-FileCopyrightText: 2007 OpenedHand Ltd.
+// SPDX-FileCopyrightText: 2009 Intel Ltd.
+// SPDX-FileCopyrightText: 2012 Emmanuele Bassi
+// SPDX-FileCopyrightText: 2017 Endless
+// SPDX-FileCopyrightText: 2022 Frederic Martinsons
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -48,7 +56,7 @@ GType test_object_get_type (void);
 static TestBoxed *
 test_boxed_copy (const TestBoxed *src)
 {
-  TestBoxed *copy = g_slice_new (TestBoxed);
+  TestBoxed *copy = g_new (TestBoxed, 1);
 
   *copy = *src;
 
@@ -59,9 +67,7 @@ static void
 test_boxed_free (TestBoxed *boxed)
 {
   if (G_LIKELY (boxed))
-    {
-      g_slice_free (TestBoxed, boxed);
-    }
+    g_free (boxed);
 }
 
 GType
